/*******************************************************************************
 *    UART2.h
 *  2025.3.3 Suwa-Koubou
 */

#ifndef	_UART2_H
#define	_UART2_H

/*==============================================================================
    Function Prototypes
==============================================================================*/

void UART2Init();

int  UART2GetTxSize();
int  UART2GetTrmtStat();
void UART2TxBufClr(void);
int  UART2PutChar(char ch);
void UART2PutChar_wait(char ch);
void UART2PrintString(char *str);
int  UART2PutData(char *data, int len);
void UART2PutData_wait(char *data, int len);

int  UART2IsPressed(void);
int  UART2GetRxSize(void);
void UART2RxBufClr(void);
int  UART2GetChar();
char *UART2GetString(char *buf, int size);
void UART2GetData(char *data, int len);

void UART2PutDec(int val);
void UART2PutHex(int toPrint);
void UART2PutHexWord(unsigned int toPrint);
void UART2PutHexDWord(unsigned long int toPrint);
char UART2Char2Hex(char ch);
char UART2Hex2Char(char hex);

#endif

/*** end of UART2.h ***********************************************************/
